package id.ac.polinema.notesapp.fragments;


import android.content.Context;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.design.widget.FloatingActionButton;
import android.support.v4.app.Fragment;
import android.support.v7.widget.GridLayoutManager;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;

import id.ac.polinema.notesapp.Constant;
import id.ac.polinema.notesapp.R;
import id.ac.polinema.notesapp.adapters.NoteAdapter;

/**
 * A simple {@link Fragment} subclass.
 */
public class NoteFragment extends Fragment {

	private static final String TAG = NoteFragment.class.getSimpleName();

	private RecyclerView recyclerView;
	private NoteAdapter adapter;
	private OnNoteFragmentListener listener;


	public NoteFragment() {
	}

	@Override
	public void onCreate(@Nullable Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setHasOptionsMenu(true);
	}

	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container,
													 Bundle savedInstanceState) {
		// Inflate the layout for this fragment
		View view = inflater.inflate(R.layout.fragment_note, container, false);
		recyclerView = view.findViewById(R.id.rv_notes);

		FloatingActionButton fab = view.findViewById(R.id.fab);
		fab.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View view) {
				if (listener != null) {
                    listener.onAddButtonClicked();
				}
			}
		});

		adapter = new NoteAdapter(getContext());
		recyclerView.setAdapter(adapter);
        listener.onNotesLoad(adapter);
        displayAsGrid();

		return view;
	}

	@Override
	public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.menu_note, menu);
		super.onCreateOptionsMenu(menu, inflater);
	}

	private void displayAsList() {
		RecyclerView.LayoutManager layoutManager = new LinearLayoutManager(getContext());
		recyclerView.setLayoutManager(layoutManager);
		adapter.setLayout(Constant.LAYOUT_MODE_LIST);
	}

	private void displayAsGrid() {
		RecyclerView.LayoutManager layoutManager = new GridLayoutManager(getContext(), 2);
		recyclerView.setLayoutManager(layoutManager);
		adapter.setLayout(Constant.LAYOUT_MODE_GRID);
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
			case R.id.action_show_list:
				displayAsList();
				return true;
			case R.id.action_show_grid:
				displayAsGrid();
				return true;

			case R.id.action_logout:
				Log.i(TAG, "Logout click");
				if (listener != null) {
					listener.onLogoutMenuClicked();
				}
				return true;
		}
		return super.onOptionsItemSelected(item);
	}

	@Override
	public void onAttach(Context context) {
		super.onAttach(context);
		if (context instanceof OnNoteFragmentListener) {
			listener = (OnNoteFragmentListener) context;
		} else {
			throw new RuntimeException(context.toString()
					+ "must implement OnNoteFragmentListener");
		}
	}

	@Override
	public void onDetach() {
		super.onDetach();
		listener = null;
	}

	public interface OnNoteFragmentListener {
	    void onNotesLoad(NoteAdapter adapter);
		void onAddButtonClicked();
		void onLogoutMenuClicked();
	}

}
